% Some application of logical vectors in Matlab
% Prepared by Gilberto E. Urroz, August 2004
echo on

% Examples of logical statements:
3 == 3
pause
5<6
pause
4<2
pause
3<=2
pause

%This is a logical vector:
[3<2 3>2 5~=6 5>=6 4==2 4~=2]
pause

% Operations with logical vectors:
% --- first: product with a scalar:
5*[3<2 3>2 5~=6 5>=6 4==2 4~=2]
pause

% --- next: term-by-term product with a numerical vector:
[1 2 3 4 5 6].*[3<2 3>2 5<=6 5>=6 4==2 4~=2]
pause

% --- next: term-by-term product of a logical matrix with a numerical matrix:
A = [1,2;5,4]             % numerical matrix
B = [1~=2,3>=2;4<=3,2~=1] % logical matrix
A.*B
pause

% -- next: addition of the two matrices 
A+B
pause

% Applications of logical vectors
% 1 - Eliminating infinite values in a graph
x = [-3/2*pi:pi/100:3/2*pi];y=tan(x);
plot(x,y);
pause

% Better plot:
y = y.*(abs(y)<1e10);
plot(x,y);
pause

% 2 - Eliminating a division by zero
x = [-4*pi:pi/20:4*pi];
y = sin(x)./x;
pause

% substitute the zero elements in x with MATLABs constant 'eps'
eps          % -- value of eps
pause

% replace those zero elements in x with the value 'eps':
x = x + (x==0)*eps;
pause

% complete calculation and graph
y = sin(x)./x;
plot(x,y)
pause

% 3 -  Producing a discontinuous graph by eliminating negative values
% First, we show the regular plot:
x = [-6*pi:pi/100:6*pi];
y = cos(x);
plot(x,y); axis([-22 22 -1.5 1.5])
pause

% Then, we eliminate negative values:
y = y.*(y>0);
plot(x,y); axis([-22 22 -1.5 1.5])
pause

% 4 - Clipping the tips of the cosine wave
% Keep values such that -0.98 < y < 0.98, while those outside of that interval 
% are converted to zero. 
x = [-4*pi:pi/100:4*pi];
y = cos(x);
y = y.*(y>=-0.98 & y<=0.98);
plot(x,y)
pause

% A graph that preserves the tips of the cosine wave crests while reducing 
% the remaining values to zero is produced next:
x = [-4*pi:pi/100:4*pi];
y = cos(x);
y = y.*(y<=-0.98 | y>=0.98);
plot(x,y)
% End of script

